@@ -11,7 +11,7 @@ from .descriptors import DiffResultDescriptor
 from .difference import Difference, DifferenceResult, Wrapper
 
 
-@dataclass(frozen=True)
+@dataclass(frozen=True, order=True)
 class ModifiedIbendportcon(DifferenceResult):
 
     """Difference details for a modified ibendportcon."""
@@ -20,31 +20,23 @@ class ModifiedIbendportcon(DifferenceResult):
     added_context: Context
     removed_context: Context
 
-    def __lt__(self, other) -> bool:
-        return self.rule < other.rule
-
 
 class IbendportconsDifference(Difference):
 
     """Determine the difference in ibendportcons between two policies."""
 
-    added_ibendportcons = DiffResultDescriptor("diff_ibendportcons")
-    removed_ibendportcons = DiffResultDescriptor("diff_ibendportcons")
-    modified_ibendportcons = DiffResultDescriptor("diff_ibendportcons")
-
     def diff_ibendportcons(self) -> None:
         """Generate the difference in ibendportcons between the policies."""
 
         self.log.info(
-            "Generating ibendportcon differences from {0.left_policy} to {0.right_policy}".
-            format(self))
+            f"Generating ibendportcon differences from {self.left_policy} to {self.right_policy}")
 
         self.added_ibendportcons, self.removed_ibendportcons, matched_ibendportcons = \
             self._set_diff(
                 (IbendportconWrapper(n) for n in self.left_policy.ibendportcons()),
                 (IbendportconWrapper(n) for n in self.right_policy.ibendportcons()))
 
-        self.modified_ibendportcons = []
+        self.modified_ibendportcons = list[ModifiedIbendportcon]()
 
         for left_ibep, right_ibep in matched_ibendportcons:
             # Criteria for modified ibendportcons
@@ -53,15 +45,19 @@ class IbendportconsDifference(Difference):
                 self.modified_ibendportcons.append(
                     ModifiedIbendportcon(left_ibep, right_ibep.context, left_ibep.context))
 
+    added_ibendportcons = DiffResultDescriptor[Ibendportcon](diff_ibendportcons)
+    removed_ibendportcons = DiffResultDescriptor[Ibendportcon](diff_ibendportcons)
+    modified_ibendportcons = DiffResultDescriptor[ModifiedIbendportcon](diff_ibendportcons)
+
     #
     # Internal functions
     #
     def _reset_diff(self) -> None:
         """Reset diff results on policy changes."""
         self.log.debug("Resetting ibendportcon differences")
-        self.added_ibendportcons = None
-        self.removed_ibendportcons = None
-        self.modified_ibendportcons = None
+        del self.added_ibendportcons
+        del self.removed_ibendportcons
+        del self.modified_ibendportcons
 
 
 class IbendportconWrapper(Wrapper[Ibendportcon]):
